Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(433)

Unified Diff: content/browser/web_contents/web_contents_impl.cc

Issue 12321144: Merge 183730 (Closed) Base URL: svn://svn.chromium.org/chrome/branches/1410/src/
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/web_contents/web_contents_impl.cc
===================================================================
--- content/browser/web_contents/web_contents_impl.cc (revision 184722)
+++ content/browser/web_contents/web_contents_impl.cc (working copy)
@@ -3408,11 +3408,15 @@
if (opener_)
opener_route_id = opener_->CreateOpenerRenderViews(instance);
// If any of the renderers for this WebContents has the same SiteInstance,
// use it.
if (render_manager_.current_host()->GetSiteInstance() == instance)
return render_manager_.current_host()->GetRoutingID();
+ if (render_manager_.pending_render_view_host() &&
+ render_manager_.pending_render_view_host()->GetSiteInstance() == instance)
+ return render_manager_.pending_render_view_host()->GetRoutingID();
+
RenderViewHostImpl* rvh = render_manager_.GetSwappedOutRenderViewHost(
instance);
if (rvh)
@@ -3408,11 +3408,15 @@
if (opener_)
opener_route_id = opener_->CreateOpenerRenderViews(instance);
- // If any of the renderers for this WebContents has the same SiteInstance,
- // use it.
+ // If any of the renderers (current, pending, or swapped out) for this
+ // WebContents has the same SiteInstance, use it.
if (render_manager_.current_host()->GetSiteInstance() == instance)
return render_manager_.current_host()->GetRoutingID();
« no previous file with comments | « content/browser/web_contents/web_contents_impl.h ('k') | content/browser/web_contents/web_contents_impl_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698